@@ -117,26 +117,27 @@ void show_help(const char* executable)
 {
     printf(
         "SurgeScript version %s\n"
-        "Copyright (C) %s Alexandre Martins\n"
+        "Copyright (C) %s %s\n"
         "%s\n"
         "\n"
-        "Usage: %s [OPTIONS] <script>...\n"
+        "Usage: %s [OPTIONS] <scripts>\n"
         "Compiles and executes the given script(s).\n"
         "\n"
         "Options:\n"
-        "\t-v, --version\t\t\tshows the version of SurgeScript\n"
-        "\t-D, --debug\t\t\tprints debugging information\n"
-        "\t-h, --help\t\t\tshows this message\n"
+        "    -v, --version                         shows the version of SurgeScript\n"
+        "    -D, --debug                           prints debugging information\n"
+        "    -h, --help                            shows this message\n"
         "\n"
         "Examples:\n"
-        "\t%s script.ss\t\tcompiles and executes script.ss\n"
-        "\t%s file1.ss file2.ss\tcompiles and executes file1.ss and file2.ss\n"
-        "\t%s --debug test.ss\tcompiles and runs test.ss with debugging information\n"
-        "\t%s file.ss -- -x -y\tpasses custom arguments -x and -y to file.ss\n"
+        "    %s script.ss                 compiles and executes script.ss\n"
+        "    %s file1.ss file2.ss         compiles and executes file1.ss and file2.ss\n"
+        "    %s --debug test.ss           compiles and runs test.ss with debugging information\n"
+        "    %s file.ss -- -x -y          passes custom arguments -x and -y to file.ss\n"
         "\n"
         "Full documentation at: <%s>\n",
         surgescript_util_version(),
         surgescript_util_year(),
+        surgescript_util_authors(),
         surgescript_util_website(),
         executable,
         executable,
